@@ -2,8 +2,8 @@ use full_moon::{ast, tokenizer::TokenReference, visitors::VisitorMut};
 
 struct TriviaPurger;
 
-impl<'ast> VisitorMut<'ast> for TriviaPurger {
-    fn visit_token_reference(&mut self, token: TokenReference<'ast>) -> TokenReference<'ast> {
+impl VisitorMut for TriviaPurger {
+    fn visit_token_reference(&mut self, token: TokenReference) -> TokenReference {
         TokenReference::new(Vec::new(), token.token().to_owned(), Vec::new())
     }
 }
